@@ -13,6 +13,7 @@ from typing import (
     get_args,
     get_origin,
     Literal,
+    overload,
 )
 
 from fastmcp import FastMCP
@@ -320,9 +321,21 @@ def resolve_matricula[T](
     return wrapper
 
 
+@overload
 def controlar_acesso_matricula[T](
     func: Callable[..., Awaitable[T]],
-) -> Callable[..., Awaitable[T | str]]:
+) -> Callable[..., Awaitable[Union[T, str]]]: ...
+
+
+@overload
+def controlar_acesso_matricula[T](
+    func: Callable[..., T],
+) -> Callable[..., Union[T, str]]: ...
+
+
+def controlar_acesso_matricula[T](
+    func: Callable[..., Union[T, Awaitable[T]]],
+) -> Callable[..., Union[T, str, Awaitable[Union[T, str]]]]:
     """
     Decorator que verifica automaticamente permissões de acesso à matrícula.
 
@@ -333,42 +346,82 @@ def controlar_acesso_matricula[T](
     3. Retorna erro 401 se não houver permissão
     4. Permite execução da função se houver permissão
 
-    Funciona com funções assíncronas que tenham o parâmetro 'matricula'.
+    Funciona com funções síncronas e assíncronas que tenham o parâmetro 'matricula'.
     """
     if MCP_TRANSPORT == "http":
         # Em modo HTTP, não aplica controle de acesso
         return func
 
-    @functools.wraps(func)
-    async def wrapper(*args: Any, **kwargs: Any) -> Union[T, str]:
-        # Obtém a assinatura da função para mapear argumentos posicionais
-        sig = inspect.signature(func)
-        bound_args = sig.bind(*args, **kwargs)
-        bound_args.apply_defaults()
+    # Detecta se a função é assíncrona
+    is_async = inspect.iscoroutinefunction(func)
 
-        # Verifica se existe o parâmetro 'matricula'
-        if "matricula" in bound_args.arguments:
-            from siga_mcp.utils import verificar_permissao_acesso_matricula
+    if is_async:
 
-            matricula = bound_args.arguments["matricula"]
+        @functools.wraps(func)
+        async def async_wrapper(*args: Any, **kwargs: Any) -> Union[T, str]:
+            # Obtém a assinatura da função para mapear argumentos posicionais
+            sig = inspect.signature(func)
+            bound_args = sig.bind(*args, **kwargs)
+            bound_args.apply_defaults()
 
-            if matricula == "CURRENT_USER":
-                matricula = MATRICULA_USUARIO_ATUAL
+            # Verifica se existe o parâmetro 'matricula'
+            if "matricula" in bound_args.arguments:
+                from siga_mcp.utils import verificar_permissao_acesso_matricula
 
-            # Verifica se o usuário tem permissão para acessar esta matrícula
-            usuario_nao_pode_acessar = not verificar_permissao_acesso_matricula(
-                matricula
-            )
+                matricula = bound_args.arguments["matricula"]
 
-            if usuario_nao_pode_acessar:
-                # Retorna o nome da função para contextualizar o erro
-                func_name = func.__name__
-                return (
-                    f"Erro 401: Permissão negada para '{func_name}'. Usuário atual logado é diferente do solicitado. "
-                    "Você não pode acessar essa função. Contate seu administrador."
+                if matricula == "CURRENT_USER":
+                    matricula = MATRICULA_USUARIO_ATUAL
+
+                # Verifica se o usuário tem permissão para acessar esta matrícula
+                usuario_nao_pode_acessar = not verificar_permissao_acesso_matricula(
+                    matricula
                 )
 
-        # Chama a função original se tiver permissão
-        return await func(*args, **kwargs)
+                if usuario_nao_pode_acessar:
+                    # Retorna o nome da função para contextualizar o erro
+                    func_name = func.__name__
+                    return (
+                        f"Erro 401: Permissão negada para '{func_name}'. Usuário atual logado é diferente do solicitado. "
+                        "Você não pode acessar essa função. Contate seu administrador."
+                    )
 
-    return wrapper
+            # Chama a função original se tiver permissão
+            return await func(*args, **kwargs)  # type: ignore
+
+        return async_wrapper  # type: ignore
+    else:
+
+        @functools.wraps(func)
+        def sync_wrapper(*args: Any, **kwargs: Any) -> Union[T, str]:
+            # Obtém a assinatura da função para mapear argumentos posicionais
+            sig = inspect.signature(func)
+            bound_args = sig.bind(*args, **kwargs)
+            bound_args.apply_defaults()
+
+            # Verifica se existe o parâmetro 'matricula'
+            if "matricula" in bound_args.arguments:
+                from siga_mcp.utils import verificar_permissao_acesso_matricula
+
+                matricula = bound_args.arguments["matricula"]
+
+                if matricula == "CURRENT_USER":
+                    matricula = MATRICULA_USUARIO_ATUAL
+
+                # Verifica se o usuário tem permissão para acessar esta matrícula
+                usuario_nao_pode_acessar = not verificar_permissao_acesso_matricula(
+                    matricula
+                )
+
+                if usuario_nao_pode_acessar:
+                    # Retorna o nome da função para contextualizar o erro
+                    func_name = func.__name__
+                    return (
+                        f"Erro 401: Permissão negada para '{func_name}'. Usuário atual logado é diferente do solicitado. "
+                        "Você não pode acessar essa função. Contate seu administrador."
+                    )
+
+            # Chama a função original se tiver permissão
+            return func(*args, **kwargs)  # type: ignore
+
+        return sync_wrapper  # type: ignore
