@@ -1,4 +1,4 @@
-from siga_mcp.constants import PROJETO_TO_NUMBER
+from siga_mcp.dynamic_constants import PROJETO_TO_NUMBER
 from siga_mcp.dynamic_constants import USUARIOS_INFRAESTRUTURA_DOCSTRING
 from siga_mcp.utils import montar_string
 
