@@ -1,4 +1,5 @@
 import calendar
+from collections.abc import Sequence
 import re
 from datetime import datetime, timedelta
 from os import getenv
@@ -7,7 +8,7 @@ from msal import ConfidentialClientApplication  # pyright: ignore[reportMissingT
 import aiohttp
 import requests
 import ujson
-
+import zoneinfo
 
 from siga_mcp.constants import (
     DIAS_SEMANA_PT,
@@ -1272,7 +1273,6 @@ def send_message_to_user(user_id: str, message_text: str):
     )
 
     if message_response.status_code == 201:
-        print("Mensagem enviada com sucesso para o usuário!")
         return message_response.json()
     else:
         raise Exception(
@@ -1314,7 +1314,54 @@ def get_package_version() -> str:
                 info = cast(dict[str, Any], info)
                 version = info.get("version")
                 if isinstance(version, str) and version:
-                    return version
+                    releases = data.get("releases", {})
+                    if isinstance(releases, dict) and releases:
+                        releases = cast(dict[str, Any], releases)
+                        current_release = releases.get(version, {})
+                        if isinstance(current_release, list):
+                            current_release = cast(
+                                list[dict[str, Any]], current_release
+                            )
+                            if len(current_release) == 0:
+                                return version
+
+                            current_release = current_release[-1]
+
+                            upload_time_iso_8601 = current_release.get(
+                                "upload_time_iso_8601"
+                            )
+
+                            brazil_converted_time = ""
+                            if (
+                                isinstance(upload_time_iso_8601, str)
+                                and upload_time_iso_8601
+                            ):
+                                try:
+                                    tz_br = zoneinfo.ZoneInfo("America/Sao_Paulo")
+
+                                    # Tenta parsear
+                                    dt = datetime.fromisoformat(
+                                        upload_time_iso_8601.replace("Z", "+00:00")
+                                    )
+
+                                    # Se não tiver informação de fuso horário, consideramos que já é horário de Brasília
+                                    if dt.tzinfo is None:
+                                        dt = dt.replace(tzinfo=tz_br)
+                                    else:
+                                        # Se tiver fuso (por ex: UTC), convertemos para Brasília
+                                        dt = dt.astimezone(tz_br)
+
+                                    brazil_converted_time = dt.strftime(
+                                        "%d-%m-%Y %H:%M:%S (%Z)"
+                                    )
+                                except Exception:
+                                    brazil_converted_time = (
+                                        upload_time_iso_8601  # fallback
+                                    )
+                            else:
+                                brazil_converted_time = "N/A"
+
+                            return f"{version} - {brazil_converted_time}"
     except Exception:
         # Silenciar e seguir para fallback local
         pass
@@ -1323,12 +1370,69 @@ def get_package_version() -> str:
     return "<not found>"
 
 
-def montar_string(items: dict[str, str | int | bool], separator: str = "-") -> str:
-    print(f"        {separator} ", end="")
+def montar_string(items: dict[str, Any], separator: str = "-") -> str:
     return f"\n        {separator} ".join(
         [f'"{key}" (Código {value})' for key, value in items.items()]
     )
 
 
+# ========================================================================
+# FUNÇÃO DE NORMALIZAÇÃO DE PARÂMETROS
+# ========================================================================
+# Função utilitária para normalizar parâmetros de entrada fazendo busca
+# case-insensitive em dicionários de constantes. Evita repetição de código
+# nas funções principais e centraliza o tratamento de erros em XML.
+# ========================================================================
+def normalizar_parametro(
+    parametro: str,
+    constant_mapping: dict[str, Any],
+    data: Sequence[dict[str, Any]] | dict[str, Any] | None = None,
+    root_element_name: str = "root",
+    item_element_name: str = "item",
+    root_attributes: dict[str, str] | None = None,
+    custom_attributes: dict[str, Any] | None = None,
+) -> tuple[Any | None, str | None]:
+    """
+    Normaliza um parâmetro fazendo busca case-insensitive em um dicionário de constantes.
+
+    Retorna:
+        tuple: (valor_normalizado, None) se sucesso ou (None, xml_erro) se erro
+    """
+
+    # Garante que data seja uma lista, mesmo se None foi passado
+    data = data or []
+
+    # Busca case-insensitive: procura o parâmetro no dicionário ignorando maiúsculas/minúsculas
+    parametro_normalizado = next(
+        # Expressão geradora que itera sobre todas as chaves do dicionário
+        (
+            key
+            for key in constant_mapping.keys()
+            # Compara chave e parâmetro em minúsculas para match case-insensitive
+            if str(key).lower() == str(parametro).lower()
+        ),
+        # Se nenhuma correspondência encontrada, retorna None
+        None,
+    )
+
+    # Se parâmetro não foi encontrado no dicionário, gera erro XML
+    if parametro_normalizado is None:
+        # Constrói XML de erro com as informações fornecidas
+        xml_erro = XMLBuilder().build_xml(
+            data=data,
+            root_element_name=root_element_name,
+            item_element_name=item_element_name,
+            root_attributes=root_attributes,
+            custom_attributes=custom_attributes,
+        )
+        # Retorna tupla: (None, erro_xml) indicando falha
+        return None, xml_erro
+
+    # Parâmetro encontrado: busca o valor mapeado no dicionário
+    parametro_final = constant_mapping[parametro_normalizado]
+    # Retorna tupla: (valor_normalizado, None) indicando sucesso
+    return parametro_final, None
+
+
 if __name__ == "__main__":
-    print(montar_string({"teste": 123, "teste2": 456}))
+    print(get_package_version())
